@@ -1,13 +1,4 @@
-from .auth import PixivAuth
-from .login_response_types import (
-    LoginCred,
-    LoginInfo,
-    LoginUserInfo,
-    OAuthAPIResponse,
-    PixivLoginFailed,
-    ProfileURIs,
-)
-from .selenium import (
+from ._selenium import (
     AUTH_TOKEN_URL,
     CALLBACK_URI,
     CLIENT_ID,
@@ -18,6 +9,17 @@ from .selenium import (
     USER_AGENT,
     GetPixivToken,
 )
+from .auth import PixivAuth
+from .login_response_types import (
+    LoginCred,
+    LoginInfo,
+    LoginUserInfo,
+    OAuthAPIResponse,
+    PixivLoginFailed,
+    ProfileURIs,
+)
+
+__version__ = "2.0.0"
 
 __all__ = [
     "PixivAuth",
